@@ -43,9 +43,14 @@ class Channel(virtual.Channel):
         return item, dest
 
     def _put(self, queue, message, **kwargs):
+        extra = {}
         priority = message["properties"]["delivery_info"]["priority"]
+        ttr = message["properties"].get("ttr")
+        if ttr is not None:
+            extra["ttr"] = ttr
+
         self.client.use(queue)
-        self.client.put(dumps(message), priority=priority)
+        self.client.put(dumps(message), priority=priority, **extra)
 
     def _get(self, queue):
         if queue not in self.client.watching():
